FlutterAria2Platform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterAria2Platform
Implementers

Constructors

FlutterAria2Platform()

Properties

hashCode int
The hash code for this object.
no setterinherited
onDownloadEvent Stream<Aria2DownloadEventData>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addTorrent(String torrentFile, {List<String>? webseedUris, Map<String, String>? options, int position = -1}) Future<String>
addUri(List<String> uris, {Map<String, String>? options, int position = -1}) Future<String>
changeGlobalOption(Map<String, String> options) Future<int>
changeOption(String gid, Map<String, String> options) Future<int>
changePosition(String gid, int pos, Aria2OffsetMode how) Future<int>
getActiveDownload() Future<List<String>>
getDownloadBtMetaInfo(String gid) Future<Aria2BtMetaInfoData>
getDownloadFiles(String gid) Future<List<Aria2FileData>>
getDownloadInfo(String gid) Future<Aria2DownloadInfo>
getDownloadOption(String gid, String name) Future<String?>
getDownloadOptions(String gid) Future<Map<String, String>>
getGlobalOption(String name) Future<String?>
getGlobalOptions() Future<Map<String, String>>
getGlobalStat() Future<Aria2GlobalStat>
getPlatformVersion() Future<String?>
libraryDeinit() Future<int>
libraryInit() Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseDownload(String gid, {bool force = false}) Future<int>
removeDownload(String gid, {bool force = false}) Future<int>
run() Future<int>
sessionFinal() Future<int>
sessionNew({Map<String, String>? options, bool keepRunning = true}) Future<void>
shutdown({bool force = false}) Future<int>
startNativeRunLoop() Future<void>
在原生后台线程启动持续事件循环 (ARIA2_RUN_DEFAULT)。
stopNativeRunLoop() Future<void>
停止原生后台事件循环。
toString() String
A string representation of this object.
inherited
unpauseDownload(String gid) Future<int>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FlutterAria2Platform
getter/setter pair