Aria2DownloadEventData class
下载事件数据
Constructors
- Aria2DownloadEventData({required Aria2DownloadEvent event, required String gid})
-
const
-
Aria2DownloadEventData.fromMap(Map<
String, dynamic> map) -
factory
Properties
- event → Aria2DownloadEvent
-
事件类型
final
- gid → String
-
下载 GID(十六进制字符串)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited