Aria2FileData class
文件数据
Constructors
-
Aria2FileData({required int index, required String path, required int length, required int completedLength, required bool selected, required List<
Aria2UriData> uris}) -
const
-
Aria2FileData.fromMap(Map<
String, dynamic> map) -
factory
Properties
- completedLength → int
-
已完成大小(字节)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
文件索引(从 1 开始)
final
- length → int
-
文件总大小(字节)
final
- path → String
-
文件路径
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → bool
-
是否被选中下载
final
-
uris
→ List<
Aria2UriData> -
URI 列表
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited